import { css, LitElement, html } from 'lit-element';
import { classMap } from 'lit-html/directives/class-map.js';

const BsButtonRebootCss = css`
    *,
    *::before,
    *::after {
        box-sizing: border-box;
    }

    :host,
    :host::before,
    :host::after {
        box-sizing: border-box;
    }

    a {
        color: #007bff;
        text-decoration: none;
        background-color: transparent;
        -webkit-text-decoration-skip: objects;
    }

    a:hover {
        color: #0056b3;
        text-decoration: underline;
    }

    a:not([href]):not([tabindex]) {
        color: inherit;
        text-decoration: none;
    }

    a:not([href]):not([tabindex]):hover,
    a:not([href]):not([tabindex]):focus {
        color: inherit;
        text-decoration: none;
    }

    a:not([href]):not([tabindex]):focus {
        outline: 0;
    }

    button {
        border-radius: 0;
        text-transform: none;
    }

    button:focus {
        outline: 1px dotted;
        outline: 5px auto -webkit-focus-ring-color;
    }

    input,
    button {
        margin: 0;
        font-family: inherit;
        font-size: inherit;
        line-height: inherit;
        overflow: visible;
    }

    button,
    [type="button"],
    [type="reset"],
    [type="submit"] {
        -webkit-appearance: button;
    }

    button::-moz-focus-inner,
    [type="button"]::-moz-focus-inner,
    [type="reset"]::-moz-focus-inner,
    [type="submit"]::-moz-focus-inner {
        padding: 0;
        border-style: none;
    }

    input[type="radio"],
    input[type="checkbox"] {
        box-sizing: border-box;
        padding: 0;
    }

    input[type="date"],
    input[type="time"],
    input[type="datetime-local"],
    input[type="month"] {
        -webkit-appearance: listbox;
    }
`;

const BsButtonCommonCss = css`
    @media screen and (prefers-reduced-motion: reduce) {
        .btn {
            transition: none;
        }
    }

    :host {
        display: var(--btn-display, inline-block);
        width: var(--btn-width);
        z-index: var(--btn-z-index-focus);
    }

    .btn {
        user-select: none;
        -moz-user-select: none;
        -webkit-user-select: none;
        color: var(--btn-text-color);
        background-color: var(--btn-bg-color);
        border-width: var(--btn-bd-width, 1px);
        border-style: var(--btn-bd-style, solid);
        border-color: var(--btn-bd-color, transparent);
        border-top-left-radius: var(--btn-bd-top-left-radius, 0.25rem);
        border-top-right-radius: var(--btn-bd-top-right-radius, 0.25rem);
        border-bottom-right-radius: var(--btn-bd-bottom-right-radius, 0.25rem);
        border-bottom-left-radius: var(--btn-bd-bottom-left-radius, 0.25rem);
        display: var(--btn-display, inline-block);
        font-weight: var(--btn-font-weight, 400);
        text-align: var(--btn-text-align, center);
        white-space: var(--btn-white-space, nowrap);
        vertical-align: var(--btn-vertical-align, middle);
        width: var(--btn-width);
        height: var(--btn-height);
        flex: var(--btn-flex);
        padding-top: var(--btn-pd-top, 0.375rem);
        padding-bottom: var(--btn-pd-bottom, 0.375rem);
        padding-left: var(--btn-pd-left, 0.75rem);
        padding-right: var(--btn-pd-right, 0.75rem);
        font-size: var(--btn-font-size, 1rem);
        line-height: var(--btn-line-height, 1.5);
        position: var(--btn-position);
        margin-top: var(--btn-mg-top);
        margin-top: var(--btn-mg-right);
        margin-left: var(--btn-mg-left);
        margin-bottom: var(--btn-mg-bottom);
        transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out,
            border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;
    }

    .btn::after {
        display: var(--btn-display-after);
        width: var(--btn-width-after);
        height: var(--btn-height-after);
        margin-left: var(--btn-margin-left-after);
        vertical-align: var(--btn-vertical-align-after);
        content: var(--btn-content-after);
        border-top: var(--btn-border-top-after);
        border-right: var(--btn-border-right-after);
        border-bottom: var(--btn-border-bottom-after);
        border-left: var(--btn-border-left-after);
    }

    .btn:empty::after {
        margin-left: var(--btn-margin-left-empty-after);
    }

    .btn::before {
        display: var(--btn-display-before);
        width: var(--btn-width-before);
        height: var(--btn-height-before);
        margin-left: var(--btn-margin-left-before);
        vertical-align: var(--btn-vertical-align-before);
        content: var(--btn-content-before);
        border-top: var(--btn-border-top-before);
        border-right: var(--btn-border-right-before);
        border-bottom: var(--btn-border-bottom-before);
        border-left: var(--btn-border-left-before);
    }

    .btn:hover {
        color: var(--btn-text-color-hover, #212529);
        text-decoration: var(--btn-text-decoration-hover, none);
        z-index: var(--btn-z-index-hover);
        border-color: var(--btn-bd-color-hover);
        box-shadow: var(--btn-box-shadow-hover);
        background-color: var(--btn-bg-color-hover);
    }

    .btn:focus,
    .btn.focus {
        outline: 0;
        box-shadow: var(
            --btn-box-shadow-focus,
            0 0 0 0.2rem rgba(0, 123, 255, 0.25)
        );
    }

    :host(:not([outline])) .btn:focus,
    :host(:not([outline])) .btn.focus {
        color: var(--btn-text-color-focus);
        background-color: var(--btn-bg-color-focus);
        border-color: var(--btn-bd-color-focus);
    }

    .btn.disabled,
    .btn:disabled {
        color: var(--btn-text-color-disabled);
        background-color: var(--btn-bg-color-disabled);
        border-color: var(--btn-bd-color-disabled);
    }

    :host([disabled]) .btn {
        opacity: var(--btn-opacity-disabled, 0.65);
        pointer-events: var(--btn-pointer-events-disabled, none);
    }

    .btn:not(:disabled):not(.disabled):active,
    .btn:not(:disabled):not(.disabled).active {
        color: var(--btn-text-color-active);
        background-color: var(--btn-bg-color-active);
        border-color: var(--btn-bd-color-active);
    }

    .btn:not(:disabled):not(.disabled):active:focus,
    .btn:not(:disabled):not(.disabled).active:focus {
        box-shadow: var(--btn-box-shadow-active-focus);
    }

    :host(:not(:disabled):not(.disabled)) .btn {
        cursor: pointer;
        z-index: var(--btn-z-index-active);
    }
`;

/**
 * ButtonMixin
 *
 * @mixin BsButtonMixin
 *
 * @param {*} superclass the class to mix into
 * @exports BsButtonMixin
 *
 * @attribute toggle - Indicates whether or not the button is in toggle state
 * @attribute active - Indicates whether or not the button is in active state
 * @attribute disabled - Indicates whether or not the button is in disable state
 * @attribute dropdown-toggle - Indicates whether or not the button is in dropdown toggle state
 * @attribute outline - Indicates whether or not the button is in outline mode
 * @attribute {primary|secondary|success|info|warning|danger|light|dark|link}  context -
 * Indicates the styling context to use
 *
 * @property {Boolean} toggle - Indicates whether or not the button is in toggle state - default: false
 * @property {Boolean} active - Indicates whether or not the button is in active state - default: false
 * @property {Boolean} disabled - Indicates whether or not the button is in disabled state - default: false
 * @property {Boolean} dropdownToggle - Indicates whether or not the button is in dropdown toggle state - default: false
 *
 * @fires bs-button-click - Gets fired when button has been clicked on
 * @fires bs-button-focusout - Gets fired when button loses focus
 *
 * @cssproperty --btn-text-color - button text color
 * @cssproperty --btn-bg-color - button background color
 * @cssproperty --btn-bd-width - button border width - default: 1px
 * @cssproperty --btn-bd-style - button border style - default: solid
 * @cssproperty --btn-bd-color - button border color - default: transparent
 * @cssproperty --btn-bd-top-left-radius - button border top left radius - default: 0.25rem
 * @cssproperty --btn-bd-top-right-radius - button border top right radius - default: 0.25rem
 * @cssproperty --btn-bd-bottom-right-radius - button border bottom right radius - defaut: 0.25rem
 * @cssproperty --btn-bd-bottom-left-radius - button border bottom left radius - default 0.25rem
 * @cssproperty --btn-display - button display - default: inline-block
 * @cssproperty --btn-font-weight - button font weight - default: 400
 * @cssproperty --btn-text-align - button text align - default: center
 * @cssproperty --btn-white-space - button white space - default: nowrap
 * @cssproperty --btn-vertical-align - button vertical align - default: middle
 * @cssproperty --btn-width - button width
 * @cssproperty --btn-height - button height
 * @cssproperty --btn-flex - button flex
 * @cssproperty --btn-pd-top - button padding top - default 0.375rem
 * @cssproperty --btn-pd-bottom - button padding bottom - default: 0.375rem
 * @cssproperty --btn-pd-left - button padding left - default: 0.75rem
 * @cssproperty --btn-pd-right - button padding right - default: 0.75rem
 * @cssproperty --btn-font-size - button font size - default: 1rem
 * @cssproperty --btn-line-height- button line height - default: 1.5
 * @cssproperty --btn-position - button position
 * @cssproperty --btn-mg-top - button margin top
 * @cssproperty --btn-mg-right - button margin right
 * @cssproperty --btn-mg-left - button margin left
 * @cssproperty --btn-mg-bottom - button margin bottom
 * @cssproperty --btn-display-after - button ::after display
 * @cssproperty --btn-width-after - button ::after width
 * @cssproperty --btn-height-after - button ::after height
 * @cssproperty --btn-margin-left-after - button ::after margin left
 * @cssproperty --btn-vertical-align-after - button ::after vertical align
 * @cssproperty --btn-content-after - button ::after content
 * @cssproperty --btn-border-top-after - button ::after border top
 * @cssproperty --btn-border-right-after - button ::after border right after
 * @cssproperty --btn-border-bottom-after - button ::after border bottom
 * @cssproperty --btn-border-left-after - button ::after border left
 * @cssproperty --btn-margin-left-empty-after button ::after:empty margin left
 * @cssproperty --btn-display-before - button ::before display
 * @cssproperty --btn-width-before - button ::before width
 * @cssproperty --btn-height-before - button ::before height
 * @cssproperty --btn-margin-left-before - button ::before margin left
 * @cssproperty --btn-vertical-align-before - button ::before vertical align
 * @cssproperty --btn-content-before - button ::before content
 * @cssproperty --btn-border-top-before - button ::before border top
 * @cssproperty --btn-border-right-before - button ::before border right
 * @cssproperty --btn-border-bottom-before - button ::before border bottom
 * @cssproperty --btn-border-left-before - button ::before border left
 * @cssproperty --btn-text-color-hover - button hover text color - default: #212529
 * @cssproperty --btn-text-decoration-hover - button hover text decoration - default: none
 * @cssproperty --btn-z-index-hover - button hover z-index
 * @cssproperty --btn-bd-color-hover - button hover border color
 * @cssproperty --btn-box-shadow-hover - button hover box shadow
 * @cssproperty --btn-bg-color-hover - button hover background color
 * @cssproperty --btn-box-shadow-focus - button focus box-shadow - default: 0 0 0 0.2rem rgba(0, 123, 255, 0.25)
 * @cssproperty --btn-text-color-focus - button focus text color
 * @cssproperty --btn-z-index-focus - button focus z-index
 * @cssproperty --btn-bg-color-focus - button focus background color
 * @cssproperty --btn-bd-color-focus - button focus border color
 * @cssproperty --btn-text-color-disabled - button disabled text color
 * @cssproperty --btn-bg-color-disabled - button disabled background color
 * @cssproperty --btn-bd-color-disabled - button disabled border color
 * @cssproperty --btn-opacity-disabled - button disabled opacity - default: 0.65
 * @cssproperty --btn-pointer-events-disabled - button disabled pointer-events - default: none
 * @cssproperty --btn-text-color-active - button active text color
 * @cssproperty --btn-bg-color-active - button active background color
 * @cssproperty --btn-bd-color-active - button active border color
 * @cssproperty --btn-box-shadow-active-focus - button active focus box-shadow
 * @cssproperty --btn-z-index-active - button active z-index
 */

const BsButtonMixin = superclass =>
/**
 * Class mixin for button elements
 *
 * @mixin
 */
class extends superclass {
  static get properties() {
    return {
      toggle: {
        type: Boolean,
        reflect: true
      },
      active: {
        type: Boolean,
        reflect: true
      },
      disabled: {
        type: Boolean,
        reflect: true
      },
      dropdownToggle: {
        type: Boolean,
        reflect: true,
        attribute: "dropdown-toggle"
      }
    };
  }

  static get styles() {
    return [BsButtonRebootCss, BsButtonCommonCss];
  }

  constructor(...args) {
    super(...args);
    this.active = false;
    this.toggle = false;
    this.disabled = false;
    this.dropdownToggle = false;

    this._addAriaRole();
  }
  /**
   * @param {Map} _updatedProperties
   */


  firstUpdated(_updatedProperties) {
    const buttonElement = this.shadowRoot.querySelector(".btn");
    buttonElement.addEventListener("click", event => this._handleButtonClick(event));
    buttonElement.addEventListener("focusout", _ => this._handleFocusOut());
  }
  /**
   * @param {Map} _changedProperties
   */


  updated(_changedProperties) {
    if (_changedProperties.has("active")) {
      this._toggleAriaPressedState();
    }

    if (_changedProperties.has("disabled")) {
      this._toggleAriaDisabledState();
    }
  }

  async activate() {
    this.active = true;
    await this.updateComplete;
  }

  async deactivate() {
    this.active = false;
    await this.updateComplete;
  }

  async disable() {
    this.disabled = true;
    await this.updateComplete;
  }

  async enable() {
    this.disabled = false;
    await this.updateComplete;
  }

  _addAriaRole() {
    this.setAttribute("role", "button");
  }

  _toggleAriaDisabledState() {
    if (this.disabled) {
      this.setAttribute("tabindex", "-1");
      this.setAttribute("aria-disabled", "true");
    } else {
      this.removeAttribute("tabindex");
      this.removeAttribute("aria-disabled");
    }
  }

  _toggleAriaPressedState() {
    if (this.active) {
      this.setAttribute("aria-pressed", "true");
    } else {
      this.removeAttribute("aria-pressed");
    }
  }

  async _handleFocusOut() {
    if (this.disabled) {
      return;
    }

    if (this.active && this.dropdownToggle) {
      this.active = !this.active;
      await this.updateComplete;
    }

    this._fireFocusOutEvent();
  }
  /**
   * @param {MouseEvent} event
   */


  async _handleButtonClick(event) {
    if (this.disabled) {
      return;
    }

    const buttonElement = this.shadowRoot.querySelector(".btn");
    buttonElement.focus();

    if (this.toggle || this.dropdownToggle) {
      this.active = !this.active;
      await this.updateComplete;
    }

    this._fireButtonClickEvent();
  }

  _fireFocusOutEvent() {
    const btnFocusOutEvent = new CustomEvent("bs-button-focusout", {
      bubbles: true,
      composed: true
    });
    this.dispatchEvent(btnFocusOutEvent);
  }

  _fireButtonClickEvent() {
    const btnClickedEvent = new CustomEvent("bs-button-click", {
      bubbles: true,
      composed: true,
      detail: {
        active: this.active,
        toggle: this.toggle,
        dropdown: this.dropdownToggle
      }
    });
    this.dispatchEvent(btnClickedEvent);
  }

};

/**
 * Button component
 *
 * @element bs-button
 *
 * @mixes BsButtonMixin
 * @exports BsButton
 *
 * @attribute type - The type of HTMLButtonElement to use
 * @attribute toggle - Indicates whether or not the button is in toggle state
 * @attribute active - Indicates whether or not the button is in active state
 * @attribute disabled - Indicates whether or not the button is in disable state
 * @attribute dropdown-toggle - Indicates whether or not the button is in dropdown toggle state
 * @attribute outline - Indicates whether or not the button is in outline mode
 * @attribute {primary|secondary|success|info|warning|danger|light|dark|link} context -
 * Indicates the styling context to use
 *
 * @property {String} type - Indicates type of HTMLButtonElement to use. default: 'button'
 * @property {Boolean} toggle - Indicates whether or not the button is in toggle state. default: false
 * @property {Boolean} active - Indicates whether or not the button is in active state. default: false
 * @property {Boolean} disabled - Indicates whether or not the button is in disabled state. default: false
 * @property {Boolean} dropdownToggle - Indicates whether or not the button is in dropdown toggle state. default: false
 *
 * @fires bs-button-click - Gets fired when button has been clicked on
 * @fires bs-button-focusout - Gets fired when button loses focus
 *
 * @cssproperty --btn-text-color - button text color
 * @cssproperty --btn-bg-color - button background color
 * @cssproperty --btn-bd-width - button border width - default: 1px
 * @cssproperty --btn-bd-style - button border style - default: solid
 * @cssproperty --btn-bd-color - button border color - default: transparent
 * @cssproperty --btn-bd-top-left-radius - button border top left radius - default: 0.25rem
 * @cssproperty --btn-bd-top-right-radius - button border top right radius - default: 0.25rem
 * @cssproperty --btn-bd-bottom-right-radius - button border bottom right radius - defaut: 0.25rem
 * @cssproperty --btn-bd-bottom-left-radius - button border bottom left radius - default 0.25rem
 * @cssproperty --btn-display - button display - default: inline-block
 * @cssproperty --btn-font-weight - button font weight - default: 400
 * @cssproperty --btn-text-align - button text align - default: center
 * @cssproperty --btn-white-space - button white space - default: nowrap
 * @cssproperty --btn-vertical-align - button vertical align - default: middle
 * @cssproperty --btn-width - button width
 * @cssproperty --btn-height - button height
 * @cssproperty --btn-flex - button flex
 * @cssproperty --btn-pd-top - button padding top - default 0.375rem
 * @cssproperty --btn-pd-bottom - button padding bottom - default: 0.375rem
 * @cssproperty --btn-pd-left - button padding left - default: 0.75rem
 * @cssproperty --btn-pd-right - button padding right - default: 0.75rem
 * @cssproperty --btn-font-size - button font size - default: 1rem
 * @cssproperty --btn-line-height- button line height - default: 1.5
 * @cssproperty --btn-position - button position
 * @cssproperty --btn-mg-top - button margin top
 * @cssproperty --btn-mg-right - button margin right
 * @cssproperty --btn-mg-left - button margin left
 * @cssproperty --btn-mg-bottom - button margin bottom
 * @cssproperty --btn-display-after - button ::after display
 * @cssproperty --btn-width-after - button ::after width
 * @cssproperty --btn-height-after - button ::after height
 * @cssproperty --btn-margin-left-after - button ::after margin left
 * @cssproperty --btn-vertical-align-after - button ::after vertical align
 * @cssproperty --btn-content-after - button ::after content
 * @cssproperty --btn-border-top-after - button ::after border top
 * @cssproperty --btn-border-right-after - button ::after border right after
 * @cssproperty --btn-border-bottom-after - button ::after border bottom
 * @cssproperty --btn-border-left-after - button ::after border left
 * @cssproperty --btn-margin-left-empty-after button ::after:empty margin left
 * @cssproperty --btn-display-before - button ::before display
 * @cssproperty --btn-width-before - button ::before width
 * @cssproperty --btn-height-before - button ::before height
 * @cssproperty --btn-margin-left-before - button ::before margin left
 * @cssproperty --btn-vertical-align-before - button ::before vertical align
 * @cssproperty --btn-content-before - button ::before content
 * @cssproperty --btn-border-top-before - button ::before border top
 * @cssproperty --btn-border-right-before - button ::before border right
 * @cssproperty --btn-border-bottom-before - button ::before border bottom
 * @cssproperty --btn-border-left-before - button ::before border left
 * @cssproperty --btn-text-color-hover - button hover text color - default: #212529
 * @cssproperty --btn-text-decoration-hover - button hover text decoration - default: none
 * @cssproperty --btn-z-index-hover - button hover z-index
 * @cssproperty --btn-bd-color-hover - button hover border color
 * @cssproperty --btn-box-shadow-hover - button hover box shadow
 * @cssproperty --btn-bg-color-hover - button hover background color
 * @cssproperty --btn-box-shadow-focus - button focus box-shadow - default: 0 0 0 0.2rem rgba(0, 123, 255, 0.25)
 * @cssproperty --btn-text-color-focus - button focus text color
 * @cssproperty --btn-z-index-focus - button focus z-index
 * @cssproperty --btn-bg-color-focus - button focus background color
 * @cssproperty --btn-bd-color-focus - button focus border color
 * @cssproperty --btn-text-color-disabled - button disabled text color
 * @cssproperty --btn-bg-color-disabled - button disabled background color
 * @cssproperty --btn-bd-color-disabled - button disabled border color
 * @cssproperty --btn-opacity-disabled - button disabled opacity - default: 0.65
 * @cssproperty --btn-pointer-events-disabled - button disabled pointer-events - default: none
 * @cssproperty --btn-text-color-active - button active text color
 * @cssproperty --btn-bg-color-active - button active background color
 * @cssproperty --btn-bd-color-active - button active border color
 * @cssproperty --btn-box-shadow-active-focus - button active focus box-shadow
 * @cssproperty --btn-z-index-active - button active z-index
 */

class BsButton extends BsButtonMixin(LitElement) {
  static get properties() {
    return { ...super.properties,
      type: {
        type: String,
        reflect: true
      }
    };
  }

  render() {
    return html`
            <button
                .type="${this.type}"
                ?disabled="${this.disabled}"
                class="btn ${classMap({
      active: this.active
    })}"
            >
                <slot></slot>
            </button>
        `;
  }

  constructor() {
    super();
    this.type = "button";
  }

}
if (!window.customElements.get("bs-button")) window.customElements.define("bs-button", BsButton);

/**
 * Button link component
 *
 * @element bs-button-link
 *
 * @mixes BsButtonMixin
 * @exports BsButtonLink
 *
 * @attribute href - The link reference
 * @attribute target - The link target
 * @attribute toggle - Indicates whether or not the button is in toggle state
 * @attribute active - Indicates whether or not the button is in active state
 * @attribute disabled - Indicates whether or not the button is in disable state
 * @attribute dropdown-toggle - Indicates whether or not the button is in dropdown toggle state
 * @attribute outline - Indicates whether or not the button is in outline mode
 * @attribute {primary|secondary|success|info|warning|danger|light|dark|link} context -
 * Indicates the styling context to use
 *
 * @property {String} href - The link reference - default: ''
 * @property {String} target - The link target - default: _self
 * @property {Boolean} toggle - Indicates whether or not the button is in toggle state - default: false
 * @property {Boolean} active - Indicates whether or not the button is in active state - default: false
 * @property {Boolean} disabled - Indicates whether or not the button is in disabled state - default: false
 * @property {Boolean} dropdownToggle - Indicates whether or not the button is in dropdown toggle state - default: false
 *
 * @fires bs-button-click - Gets fired when button has been clicked on
 * @fires bs-button-focusout - Gets fired when button loses focus
 *
 * @cssproperty --btn-text-color - button text color
 * @cssproperty --btn-bg-color - button background color
 * @cssproperty --btn-bd-width - button border width - default: 1px
 * @cssproperty --btn-bd-style - button border style - default: solid
 * @cssproperty --btn-bd-color - button border color - default: transparent
 * @cssproperty --btn-bd-top-left-radius - button border top left radius - default: 0.25rem
 * @cssproperty --btn-bd-top-right-radius - button border top right radius - default: 0.25rem
 * @cssproperty --btn-bd-bottom-right-radius - button border bottom right radius - defaut: 0.25rem
 * @cssproperty --btn-bd-bottom-left-radius - button border bottom left radius - default 0.25rem
 * @cssproperty --btn-display - button display - default: inline-block
 * @cssproperty --btn-font-weight - button font weight - default: 400
 * @cssproperty --btn-text-align - button text align - default: center
 * @cssproperty --btn-white-space - button white space - default: nowrap
 * @cssproperty --btn-vertical-align - button vertical align - default: middle
 * @cssproperty --btn-width - button width
 * @cssproperty --btn-height - button height
 * @cssproperty --btn-flex - button flex
 * @cssproperty --btn-pd-top - button padding top - default 0.375rem
 * @cssproperty --btn-pd-bottom - button padding bottom - default: 0.375rem
 * @cssproperty --btn-pd-left - button padding left - default: 0.75rem
 * @cssproperty --btn-pd-right - button padding right - default: 0.75rem
 * @cssproperty --btn-font-size - button font size - default: 1rem
 * @cssproperty --btn-line-height- button line height - default: 1.5
 * @cssproperty --btn-position - button position
 * @cssproperty --btn-mg-top - button margin top
 * @cssproperty --btn-mg-right - button margin right
 * @cssproperty --btn-mg-left - button margin left
 * @cssproperty --btn-mg-bottom - button margin bottom
 * @cssproperty --btn-display-after - button ::after display
 * @cssproperty --btn-width-after - button ::after width
 * @cssproperty --btn-height-after - button ::after height
 * @cssproperty --btn-margin-left-after - button ::after margin left
 * @cssproperty --btn-vertical-align-after - button ::after vertical align
 * @cssproperty --btn-content-after - button ::after content
 * @cssproperty --btn-border-top-after - button ::after border top
 * @cssproperty --btn-border-right-after - button ::after border right after
 * @cssproperty --btn-border-bottom-after - button ::after border bottom
 * @cssproperty --btn-border-left-after - button ::after border left
 * @cssproperty --btn-margin-left-empty-after button ::after:empty margin left
 * @cssproperty --btn-display-before - button ::before display
 * @cssproperty --btn-width-before - button ::before width
 * @cssproperty --btn-height-before - button ::before height
 * @cssproperty --btn-margin-left-before - button ::before margin left
 * @cssproperty --btn-vertical-align-before - button ::before vertical align
 * @cssproperty --btn-content-before - button ::before content
 * @cssproperty --btn-border-top-before - button ::before border top
 * @cssproperty --btn-border-right-before - button ::before border right
 * @cssproperty --btn-border-bottom-before - button ::before border bottom
 * @cssproperty --btn-border-left-before - button ::before border left
 * @cssproperty --btn-text-color-hover - button hover text color - default: #212529
 * @cssproperty --btn-text-decoration-hover - button hover text decoration - default: none
 * @cssproperty --btn-z-index-hover - button hover z-index
 * @cssproperty --btn-bd-color-hover - button hover border color
 * @cssproperty --btn-box-shadow-hover - button hover box shadow
 * @cssproperty --btn-bg-color-hover - button hover background color
 * @cssproperty --btn-box-shadow-focus - button focus box-shadow - default: 0 0 0 0.2rem rgba(0, 123, 255, 0.25)
 * @cssproperty --btn-text-color-focus - button focus text color
 * @cssproperty --btn-z-index-focus - button focus z-index
 * @cssproperty --btn-bg-color-focus - button focus background color
 * @cssproperty --btn-bd-color-focus - button focus border color
 * @cssproperty --btn-text-color-disabled - button disabled text color
 * @cssproperty --btn-bg-color-disabled - button disabled background color
 * @cssproperty --btn-bd-color-disabled - button disabled border color
 * @cssproperty --btn-opacity-disabled - button disabled opacity - default: 0.65
 * @cssproperty --btn-pointer-events-disabled - button disabled pointer-events - default: none
 * @cssproperty --btn-text-color-active - button active text color
 * @cssproperty --btn-bg-color-active - button active background color
 * @cssproperty --btn-bd-color-active - button active border color
 * @cssproperty --btn-box-shadow-active-focus - button active focus box-shadow
 * @cssproperty --btn-z-index-active - button active z-index
 */

class BsButtonLink extends BsButtonMixin(LitElement) {
  static get properties() {
    return { ...super.properties,
      href: {
        type: String
      },
      target: {
        type: String
      }
    };
  }

  render() {
    return html`
            <a
                href="${this.href}"
                .target="${this.target}"
                class="btn ${classMap({
      active: this.active,
      disabled: this.disabled
    })}"
            >
                <slot></slot>
            </a>
        `;
  }

  constructor() {
    super();
    this.href = "";
    this.target = "_self";
  }
  /**
   * @param {Map} _updatedProperties
   */


  firstUpdated(_updatedProperties) {
    super.firstUpdated(_updatedProperties);
    this.addEventListener("click", event => this._handleButtonLinkClick(event));
  }

  _handleButtonLinkClick(event) {
    if (!this.href) {
      event.preventDefault();
    }
  }

}
if (!window.customElements.get("bs-button-link")) window.customElements.define("bs-button-link", BsButtonLink);

/**
 * Button component
 *
 * @element bs-button
 *
 * @mixes BsButtonMixin
 * @exports BsButton
 *
 * @attribute label - The button label
 * @attribute toggle - Indicates whether or not the button is in toggle state
 * @attribute active - Indicates whether or not the button is in active state
 * @attribute disabled - Indicates whether or not the button is in disable state
 * @attribute dropdown-toggle - Indicates whether or not the button is in dropdown toggle state
 * @attribute outline - Indicates whether or not the button is in outline mode
 * @attribute {primary|secondary|success|info|warning|danger|light|dark|link} context -
 * Indicates the styling context to use
 *
 * @property {String} label - The button label - default: ''
 * @property {Boolean} toggle - Indicates whether or not the button is in toggle state - default: false
 * @property {Boolean} active - Indicates whether or not the button is in active state - default: false
 * @property {Boolean} disabled - Indicates whether or not the button is in disabled state - default: false
 * @property {Boolean} dropdownToggle - Indicates whether or not the button is in dropdown toggle state - default: false
 *
 * @fires bs-button-click - Gets fired when button has been clicked on
 * @fires bs-button-focusout - Gets fired when button loses focus
 *
 * @cssproperty --btn-text-color - button text color
 * @cssproperty --btn-bg-color - button background color
 * @cssproperty --btn-bd-width - button border width - default: 1px
 * @cssproperty --btn-bd-style - button border style - default: solid
 * @cssproperty --btn-bd-color - button border color - default: transparent
 * @cssproperty --btn-bd-top-left-radius - button border top left radius - default: 0.25rem
 * @cssproperty --btn-bd-top-right-radius - button border top right radius - default: 0.25rem
 * @cssproperty --btn-bd-bottom-right-radius - button border bottom right radius - defaut: 0.25rem
 * @cssproperty --btn-bd-bottom-left-radius - button border bottom left radius - default 0.25rem
 * @cssproperty --btn-display - button display - default: inline-block
 * @cssproperty --btn-font-weight - button font weight - default: 400
 * @cssproperty --btn-text-align - button text align - default: center
 * @cssproperty --btn-white-space - button white space - default: nowrap
 * @cssproperty --btn-vertical-align - button vertical align - default: middle
 * @cssproperty --btn-width - button width
 * @cssproperty --btn-height - button height
 * @cssproperty --btn-flex - button flex
 * @cssproperty --btn-pd-top - button padding top - default 0.375rem
 * @cssproperty --btn-pd-bottom - button padding bottom - default: 0.375rem
 * @cssproperty --btn-pd-left - button padding left - default: 0.75rem
 * @cssproperty --btn-pd-right - button padding right - default: 0.75rem
 * @cssproperty --btn-font-size - button font size - default: 1rem
 * @cssproperty --btn-line-height- button line height - default: 1.5
 * @cssproperty --btn-position - button position
 * @cssproperty --btn-mg-top - button margin top
 * @cssproperty --btn-mg-right - button margin right
 * @cssproperty --btn-mg-left - button margin left
 * @cssproperty --btn-mg-bottom - button margin bottom
 * @cssproperty --btn-display-after - button ::after display
 * @cssproperty --btn-width-after - button ::after width
 * @cssproperty --btn-height-after - button ::after height
 * @cssproperty --btn-margin-left-after - button ::after margin left
 * @cssproperty --btn-vertical-align-after - button ::after vertical align
 * @cssproperty --btn-content-after - button ::after content
 * @cssproperty --btn-border-top-after - button ::after border top
 * @cssproperty --btn-border-right-after - button ::after border right after
 * @cssproperty --btn-border-bottom-after - button ::after border bottom
 * @cssproperty --btn-border-left-after - button ::after border left
 * @cssproperty --btn-margin-left-empty-after button ::after:empty margin left
 * @cssproperty --btn-display-before - button ::before display
 * @cssproperty --btn-width-before - button ::before width
 * @cssproperty --btn-height-before - button ::before height
 * @cssproperty --btn-margin-left-before - button ::before margin left
 * @cssproperty --btn-vertical-align-before - button ::before vertical align
 * @cssproperty --btn-content-before - button ::before content
 * @cssproperty --btn-border-top-before - button ::before border top
 * @cssproperty --btn-border-right-before - button ::before border right
 * @cssproperty --btn-border-bottom-before - button ::before border bottom
 * @cssproperty --btn-border-left-before - button ::before border left
 * @cssproperty --btn-text-color-hover - button hover text color - default: #212529
 * @cssproperty --btn-text-decoration-hover - button hover text decoration - default: none
 * @cssproperty --btn-z-index-hover - button hover z-index
 * @cssproperty --btn-bd-color-hover - button hover border color
 * @cssproperty --btn-box-shadow-hover - button hover box shadow
 * @cssproperty --btn-bg-color-hover - button hover background color
 * @cssproperty --btn-box-shadow-focus - button focus box-shadow - default: 0 0 0 0.2rem rgba(0, 123, 255, 0.25)
 * @cssproperty --btn-text-color-focus - button focus text color
 * @cssproperty --btn-z-index-focus - button focus z-index
 * @cssproperty --btn-bg-color-focus - button focus background color
 * @cssproperty --btn-bd-color-focus - button focus border color
 * @cssproperty --btn-text-color-disabled - button disabled text color
 * @cssproperty --btn-bg-color-disabled - button disabled background color
 * @cssproperty --btn-bd-color-disabled - button disabled border color
 * @cssproperty --btn-opacity-disabled - button disabled opacity - default: 0.65
 * @cssproperty --btn-pointer-events-disabled - button disabled pointer-events - default: none
 * @cssproperty --btn-text-color-active - button active text color
 * @cssproperty --btn-bg-color-active - button active background color
 * @cssproperty --btn-bd-color-active - button active border color
 * @cssproperty --btn-box-shadow-active-focus - button active focus box-shadow
 * @cssproperty --btn-z-index-active - button active z-index
 */

class BsButtonInput extends BsButtonMixin(LitElement) {
  static get properties() {
    return { ...super.properties,
      label: {
        type: String
      }
    };
  }

  render() {
    return html`
            <input
                type="button"
                value="${this.label}"
                ?disabled="${this.disabled}"
                class="btn ${classMap({
      active: this.active
    })}"
            />
        `;
  }

  constructor() {
    super();
    this.label = "";
  }

}
if (!window.customElements.get("bs-button-input")) window.customElements.define("bs-button-input", BsButtonInput);

const BsButtonBlockCss = css`
    bs-button[block],
    bs-button-link[block],
    bs-button-input[block] {
        display: block;
        --btn-width: 100%;
    }

    bs-button[block]:not(:first-child),
    bs-button-link[block]:not(:first-child),
    bs-button-input[block]:not(:first-child) {
        margin-top: 0.5rem;
    }
`;

const BsButtonDangerCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --danger-color: var(--danger, #dc3545);
    }

    bs-button[context="danger"]:not([outline]),
    bs-button-link[context="danger"]:not([outline]),
    bs-button-input[context="danger"]:not([outline]) {
        --btn-text-color: var(--btn-danger-text-color, #fff);
        --btn-bg-color: var(--btn-danger-bg-color, var(--danger-color));
        --btn-bd-color: var(--btn-danger-bd-color, var(--danger-color));
        --btn-text-color-hover: var(--btn-danger-text-color-hover, #fff);
        --btn-bg-color-hover: var(--btn-danger-bg-color-hover, #c82333);
        --btn-bd-color-hover: var(--btn-danger-bd-color-hover, #bd2130);
        --btn-bd-color-focus: var(--btn-danger-bd-color-focus, #bd2130);
        --btn-bg-color-focus: var(--btn-danger-bg-color-focus, #c82333);
        --btn-text-color-focus: var(--btn-danger-text-color-focus, #fff);
        --btn-box-shadow-focus: var(
            --btn-danger-box-shadow-focus,
            0 0 0 0.2rem rgba(220, 53, 69, 0.5)
        );
        --btn-text-color-disabled: var(--btn-danger-text-color-disabled, #fff);
        --btn-bg-color-disabled: var(
            --btn-danger-bg-color-disabled,
            var(--danger-color)
        );
        --btn-bd-color-disabled: var(
            --btn-danger-bd-color-disabled,
            var(--danger-color)
        );
        --btn-text-color-active: var(--btn-danger-text-color-active, #fff);
        --btn-bg-color-active: var(--btn-danger-bg-color-active, #bd2130);
        --btn-bd-color-active: var(--btn-danger-bd-color-active, #b21f2d);
        --btn-box-shadow-active-focus: var(
            --btn-danger-box-shadow-active-focus,
            0 0 0 0.2rem rgba(220, 53, 69, 0.5)
        );
    }

    bs-button[context="danger"][outline],
    bs-button-link[context="danger"][outline],
    bs-button-input[context="danger"][outline] {
        --btn-text-color: var(
            --btn-outline-danger-text-color,
            var(--danger-color)
        );
        --btn-bg-color: var(--btn-outline-danger-bg-color, transparent);
        --btn-bd-color: var(--btn-outline-danger-bd-color, var(--danger-color));
        --btn-text-color-hover: var(
            --btn-outline-danger-text-color-hover,
            #fff
        );
        --btn-bg-color-hover: var(
            --btn-outline-danger-bg-color-hover,
            var(--danger-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-danger-bd-color-hover,
            var(--danger-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-danger-box-shadow-focus,
            0 0 0 0.2rem rgba(220, 53, 69, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-danger-text-color-disabled,
            var(--danger-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-danger-bg-color-disabled,
            #transparent
        );
        --btn-text-color-active: var(
            --btn-outline-danger-text-color-active,
            #fff
        );
        --btn-bg-color-active: var(
            --btn-outline-danger-bg-color-active,
            var(--danger-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-danger-bd-color-active,
            var(--danger-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-danger-box-shadow-active-focus,
            0 0 0 0.2rem rgba(220, 53, 69, 0.5)
        );
    }
`;

const BsButtonDarkCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --dark-color: var(--dark, #343a40);
    }

    bs-button[context="dark"]:not([outline]),
    bs-button-link[context="dark"]:not([outline]),
    bs-button-input[context="dark"]:not([outline]) {
        --btn-text-color: var(--btn-dark-text-color, #fff);
        --btn-bg-color: var(--btn-dark-bg-color, var(--dark-color));
        --btn-bd-color: var(--btn-dark-bd-color, var(--dark-color));
        --btn-text-color-hover: var(--btn-dark-text-color-hover, #fff);
        --btn-bg-color-hover: var(--btn-dark-bg-color-hover, #23272b);
        --btn-bd-color-hover: var(--btn-dark-bd-color-hover, #1d2124);
        --btn-bd-color-focus: var(--btn-dark-bd-color-focus, #1d2124);
        --btn-bg-color-focus: var(--btn-dark-bg-color-focus, #23272b);
        --btn-text-color-focus: var(--btn-dark-text-color-focus, #fff);
        --btn-box-shadow-focus: var(
            --btn-dark-box-shadow-focus,
            0 0 0 0.2rem rgba(52, 58, 64, 0.5)
        );
        --btn-text-color-disabled: var(--btn-dark-text-color-disabled, #fff);
        --btn-bg-color-disabled: var(
            --btn-dark-bg-color-disabled,
            var(--dark-color)
        );
        --btn-bd-color-disabled: var(
            --btn-dark-bd-color-disabled,
            var(--dark-color)
        );
        --btn-text-color-active: var(--btn-dark-text-color-active, #fff);
        --btn-bg-color-active: var(--btn-dark-bg-color-active, #1d2124);
        --btn-bd-color-active: var(--btn-dark-bd-color-active, #171a1d);
        --btn-box-shadow-active-focus: var(
            --btn-dark-box-shadow-active-focus,
            0 0 0 0.2rem rgba(52, 58, 64, 0.5)
        );
    }

    bs-button[context="dark"][outline],
    bs-button-link[context="dark"][outline],
    bs-button-input[context="dark"][outline] {
        --btn-text-color: var(--btn-outline-dark-text-color, var(--dark-color));
        --btn-bg-color: var(--btn-outline-dark-bg-color, transparent);
        --btn-bd-color: var(--btn-outline-dark-bd-color, var(--dark-color));
        --btn-text-color-hover: var(--btn-outline-dark-text-color-hover, #fff);
        --btn-bg-color-hover: var(
            --btn-outline-dark-bg-color-hover,
            var(--dark-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-dark-bd-color-hover,
            var(--dark-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-dark-box-shadow-focus,
            0 0 0 0.2rem rgba(52, 58, 64, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-dark-text-color-disabled,
            var(--dark-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-dark-bg-color-disabled,
            #transparent
        );
        --btn-text-color-active: var(
            --btn-outline-dark-text-color-active,
            #fff
        );
        --btn-bg-color-active: var(
            --btn-outline-dark-bg-color-active,
            var(--dark-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-dark-bd-color-active,
            var(--dark-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-dark-box-shadow-active-focus,
            0 0 0 0.2rem rgba(52, 58, 64, 0.5)
        );
    }
`;

const BsButtonInfoCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --info-color: var(--info, #17a2b8);
    }

    bs-button[context="info"]:not([outline]),
    bs-button-link[context="info"]:not([outline]),
    bs-button-input[context="info"]:not([outline]) {
        --btn-text-color: var(--btn-info-text-color, #fff);
        --btn-bg-color: var(--btn-info-bg-color, var(--info-color));
        --btn-bd-color: var(--btn-info-bd-color, var(--info-color));
        --btn-text-color-hover: var(--btn-info-text-color-hover, #fff);
        --btn-bg-color-hover: var(--btn-info-bg-color-hover, #138496);
        --btn-bd-color-hover: var(--btn-info-bd-color-hover, #117a8b);
        --btn-bd-color-focus: var(--btn-info-bd-color-focus, #117a8b);
        --btn-bg-color-focus: var(--btn-info-bg-color-focus, #138496);
        --btn-text-color-focus: var(--btn-info-text-color-focus, #fff);
        --btn-box-shadow-focus: var(
            --btn-info-box-shadow-focus,
            0 0 0 0.2rem rgba(23, 162, 184, 0.5)
        );
        --btn-text-color-disabled: var(--btn-info-text-color-disabled, #fff);
        --btn-bg-color-disabled: var(
            --btn-info-bg-color-disabled,
            var(--info-color)
        );
        --btn-bd-color-disabled: var(
            --btn-info-bd-color-disabled,
            var(--info-color)
        );
        --btn-text-color-active: var(--btn-info-text-color-active, #fff);
        --btn-bg-color-active: var(--btn-info-bg-color-active, #117a8b);
        --btn-bd-color-active: var(--btn-info-bd-color-active, #10707f);
        --btn-box-shadow-active-focus: var(
            --btn-info-box-shadow-active-focus,
            0 0 0 0.2rem rgba(23, 162, 184, 0.5)
        );
    }

    bs-button[context="info"][outline],
    bs-button-link[context="info"][outline],
    bs-button-input[context="info"][outline] {
        --btn-text-color: var(--btn-outline-info-text-color, var(--info-color));
        --btn-bg-color: var(--btn-outline-info-bg-color, transparent);
        --btn-bd-color: var(--btn-outline-info-bd-color, var(--info-color));
        --btn-text-color-hover: var(--btn-outline-info-text-color-hover, #fff);
        --btn-bg-color-hover: var(
            --btn-outline-info-bg-color-hover,
            var(--info-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-info-bd-color-hover,
            var(--info-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-info-box-shadow-focus,
            0 0 0 0.2rem rgba(23, 162, 184, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-info-text-color-disabled,
            var(--info-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-info-bg-color-disabled,
            #transparent
        );
        --btn-text-color-active: var(
            --btn-outline-info-text-color-active,
            #fff
        );
        --btn-bg-color-active: var(
            --btn-outline-info-bg-color-active,
            var(--info-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-info-bd-color-active,
            var(--info-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-info-box-shadow-active-focus,
            0 0 0 0.2rem rgba(23, 162, 184, 0.5)
        );
    }
`;

const BsButtonSizeCss = css`
    bs-button[size="small"],
    bs-button-link[size="small"],
    bs-button-input[size="small"] {
        --btn-pd-top: var(--bs-btn-small-top-pd, 0.25rem);
        --btn-pd-bottom: var(--bs-btn-small-bottom-pd, 0.25rem);
        --btn-pd-left: var(--bs-btn-small-left-pd, 0.5rem);
        --btn-pd-right: var(--bs-btn-small-right-pd, 0.5rem);
        --btn-font-size: var(--bs-btn-small-font-size, 0.875rem);
        --btn-line-height: var(--bs-btn-small-line-height, 1.5);
        --btn-bd-top-left-radius: var(
            --bs-btn-small-bd-top-left-radius,
            0.2rem
        );
        --btn-bd-top-right-radius: var(
            --bs-btn-small-bd-top-right-radius,
            0.2rem
        );
        --btn-bd-bottom-right-radius: var(
            --bs-btn-small-bd-bottom-right-radius,
            0.2rem
        );
        --btn-bd-bottom-left-radius: var(
            --bs-btn-small-bd-bottom-left-radius,
            0.2rem
        );
    }

    bs-button[size="large"],
    bs-button-link[size="large"],
    bs-button-input[size="large"] {
        --btn-pd-top: var(--bs-btn-large-top-pd, 0.5rem);
        --btn-pd-bottom: var(--bs-btn-large-bottom-pd, 0.5rem);
        --btn-pd-left: var(--bs-btn-large-left-pd, 1rem);
        --btn-pd-right: var(--bs-btn-large-right-pd, 1rem);
        --btn-font-size: var(--bs-btn-large-font-size, 1.25rem);
        --btn-line-height: var(--bs-btn-large-line-height, 1.5);
        --btn-bd-top-left-radius: var(
            --bs-btn-large-bd-top-left-radius,
            0.3rem
        );
        --btn-bd-top-right-radius: var(
            --bs-btn-large-bd-top-right-radius,
            0.3rem
        );
        --btn-bd-bottom-right-radius: var(
            --bs-btn-large-bd-bottom-right-radius,
            0.3rem
        );
        --btn-bd-bottom-left-radius: var(
            --bs-btn-large-bd-bottom-left-radius,
            0.3rem
        );
    }
`;

const BsButtonLightCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --light-color: var(--light, #f8f9fa);
    }

    bs-button[context="light"]:not([outline]),
    bs-button-link[context="light"]:not([outline]),
    bs-button-input[context="light"]:not([outline]) {
        --btn-text-color: var(--btn-light-text-color, #212529);
        --btn-bg-color: var(--btn-light-bg-color, var(--light-color));
        --btn-bd-color: var(--btn-light-bd-color, var(--light-color));
        --btn-text-color-hover: var(--btn-light-text-color-hover, #212529);
        --btn-bg-color-hover: var(--btn-light-bg-color-hover, #e2e6ea);
        --btn-bd-color-hover: var(--btn-light-bd-color-hover, #dae0e5);
        --btn-bd-color-focus: var(--btn-light-bd-color-focus, #dae0e5);
        --btn-bg-color-focus: var(--btn-primary-bg-color-focus, #e2e6ea);
        --btn-text-color-focus: var(--btn-primary-text-color-focus, #212529);
        --btn-box-shadow-focus: var(
            --btn-light-box-shadow-focus,
            0 0 0 0.2rem rgba(216, 217, 219, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-light-text-color-disabled,
            #212529
        );
        --btn-bg-color-disabled: var(
            --btn-light-bg-color-disabled,
            var(--light-color)
        );
        --btn-bd-color-disabled: var(
            --btn-light-bd-color-disabled,
            var(--light-color)
        );
        --btn-text-color-active: var(--btn-light-text-color-active, #212529);
        --btn-bg-color-active: var(--btn-light-bg-color-active, #dae0e5);
        --btn-bd-color-active: var(--btn-light-bd-color-active, #d3d9df);
        --btn-box-shadow-active-focus: var(
            --btn-light-box-shadow-active-focus,
            0 0 0 0.2rem rgba(216, 217, 219, 0.5)
        );
    }

    bs-button[context="light"][outline],
    bs-button-link[context="light"][outline],
    bs-button-input[context="light"][outline] {
        --btn-text-color: var(
            --btn-outline-light-text-color,
            var(--light-color)
        );
        --btn-bg-color: var(--btn-outline-light-bg-color, transparent);
        --btn-bd-color: var(--btn-outline-light-bd-color, var(--light-color));
        --btn-text-color-hover: var(
            --btn-outline-light-text-color-hover,
            #212529
        );
        --btn-bg-color-hover: var(
            --btn-outline-light-bg-color-hover,
            var(--light-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-light-bd-color-hover,
            var(--light-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-light-box-shadow-focus,
            0 0 0 0.2rem rgba(248, 249, 250, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-light-text-color-disabled,
            var(--light-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-light-bg-color-disabled,
            #transparent
        );
        --btn-text-color-active: var(
            --btn-outline-light-text-color-active,
            #212529
        );
        --btn-bg-color-active: var(
            --btn-outline-light-bg-color-active,
            var(--light-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-light-bd-color-active,
            var(--light-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-light-box-shadow-active-focus,
            0 0 0 0.2rem rgba(248, 249, 250, 0.5)
        );
    }
`;

const BsButtonLinkCss = css`
    bs-button[context="link"],
    bs-button-link[context="link"],
    bs-button-input[context="link"] {
        --btn-text-color: var(--btn-link-text-color, #007bff);
        --btn-bg-color: var(--btn-link-bg-color, transparent);
        --btn-font-weight: var(--btn-link-font-weight, 400);

        --btn-text-color-hover: var(--btn-link-text-color-hover, #0056b3);
        --btn-bg-color-hover: var(--btn-link-bg-color-hover, transparent);
        --btn-bd-color-hover: var(--btn-link-bd-color-hover, transparent);
        --btn-text-decoration-hover: var(
            --btn-link-text-decoration-hover,
            underline
        );

        --btn-text-color-disabled: var(--btn-link-text-color-disabled, #6c757d);
        --btn-pointer-events-disabled: var(
            --btn-link-pointer-events-disabled,
            none
        );

        --btn-text-decoration-focus: var(
            --btn-link-text-decoration-focus,
            underline
        );
        --btn-box-shadow-focus: var(--btn-link-box-shadow-focus, none);
        --btn-bd-color-focus: var(--btn--link-bd-color-focus, transparent);
    }
`;

const BsButtonPrimaryCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --primary-color: var(--primary, #007bff);
    }

    bs-button[context="primary"]:not([outline]),
    bs-button-link[context="primary"]:not([outline]),
    bs-button-input[context="primary"]:not([outline]) {
        --btn-text-color: var(--btn-primary-text-color, #fff);
        --btn-bg-color: var(--btn-primary-bg-color, var(--primary-color));
        --btn-bd-color: var(--btn-primary-bd-color, var(--primary-color));
        --btn-text-color-hover: var(--btn-primary-text-color-hover, #fff);
        --btn-bg-color-hover: var(--btn-primary-bg-color-hover, #0069d9);
        --btn-bd-color-hover: var(--btn-primary-bd-color-hover, #0062cc);
        --btn-bd-color-focus: var(--btn-primary-bd-color-focus, #0062cc);
        --btn-bg-color-focus: var(--btn-primary-bg-color-focus, #0069d9);
        --btn-text-color-focus: var(--btn-primary-text-color-focus, #fff);
        --btn-box-shadow-focus: var(
            --btn-primary-box-shadow-focus,
            0 0 0 0.2rem rgba(38, 143, 255, 0.5)
        );
        --btn-text-color-disabled: var(--btn-primary-text-color-disabled, #fff);
        --btn-bg-color-disabled: var(
            --btn-primary-bg-color-disabled,
            var(--primary-color)
        );
        --btn-bd-color-disabled: var(
            --btn-primary-bd-color-disabled,
            var(--primary-color)
        );
        --btn-text-color-active: var(--btn-primary-text-color-active, #fff);
        --btn-bg-color-active: var(--btn-primary-bg-color-active, #0062cc);
        --btn-bd-color-active: var(--btn-primary-bd-color-active, #005cbf);
        --btn-box-shadow-active-focus: var(
            --btn-primary-box-shadow-active-focus,
            0 0 0 0.2rem rgba(0, 123, 255, 0.5)
        );
    }

    bs-button[context="primary"][outline],
    bs-button-link[context="primary"][outline],
    bs-button-input[context="primary"][outline] {
        --btn-text-color: var(
            --btn-outline-primary-text-color,
            var(--primary-color)
        );
        --btn-bg-color: var(--btn-outline-primary-bg-color, transparent);
        --btn-bd-color: var(
            --btn-outline-primary-bd-color,
            var(--primary-color)
        );
        --btn-text-color-hover: var(
            --btn-outline-primary-text-color-hover,
            #fff
        );
        --btn-bg-color-hover: var(
            --btn-outline-primary-bg-color-hover,
            var(--primary-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-primary-bd-color-hover,
            var(--primary-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-primary-box-shadow-focus,
            0 0 0 0.2rem rgba(0, 123, 255, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-primary-text-color-disabled,
            var(--primary-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-primary-bg-color-disabled,
            transparent
        );
        --btn-text-color-active: var(
            --btn-outline-primary-text-color-active,
            #fff
        );
        --btn-bg-color-active: var(
            --btn-outline-primary-bg-color-active,
            var(--primary-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-primary-bd-color-active,
            var(--primary-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-primary-box-shadow-active-focus,
            0 0 0 0.2rem rgba(0, 123, 255, 0.5)
        );
    }
`;

const BsButtonSecondaryCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --secondary-color: var(--secondary, #6c757d);
    }

    bs-button[context="secondary"]:not([outline]),
    bs-button-link[context="secondary"]:not([outline]),
    bs-button-input[context="secondary"]:not([outline]) {
        --btn-text-color: var(--btn-secondary-text-color, #fff);
        --btn-bg-color: var(--btn-secondary-bg-color, var(--secondary-color));
        --btn-bd-color: var(--btn-secondary-bd-color, var(--secondary-color));
        --btn-text-color-hover: var(--btn-secondary-text-color-hover, #fff);
        --btn-bg-color-hover: var(--btn-secondary-bg-color-hover, #5a6268);
        --btn-bd-color-hover: var(--btn-secondary-bd-color-hover, #545b62);
        --btn-bd-color-focus: var(--btn-secondary-bd-color-focus, #545b62);
        --btn-bg-color-focus: var(--btn-secondary-bg-color-focus, #5a6268);
        --btn-text-color-focus: var(--btn-secondary-text-color-focus, #fff);
        --btn-box-shadow-focus: var(
            --btn-secondary-box-shadow-focus,
            0 0 0 0.2rem rgba(108, 117, 125, 0.5)
        );

        --btn-text-color-disabled: var(
            --btn-secondary-text-color-disabled,
            #fff
        );
        --btn-bg-color-disabled: var(
            --btn-secondary-bg-color-disabled,
            var(--secondary-color)
        );
        --btn-bd-color-disabled: var(
            --btn-secondary-bd-color-disabled,
            var(--secondary-color)
        );
        --btn-text-color-active: var(--btn-secondary-text-color-active, #fff);
        --btn-bg-color-active: var(--btn-secondary-bg-color-active, #545b62);
        --btn-bd-color-active: var(--btn-secondary-bd-color-active, #4e555b);
        --btn-box-shadow-active-focus: var(
            --btn-secondary-box-shadow-active-focus,
            0 0 0 0.2rem rgba(108, 117, 125, 0.5)
        );
    }

    bs-button[context="secondary"][outline],
    bs-button-link[context="secondary"][outline],
    bs-button-input[context="secondary"][outline] {
        --btn-text-color: var(
            --btn-outline-secondary-text-color,
            var(--secondary-color)
        );
        --btn-bg-color: var(--btn-outline-secondary-bg-color, transparent);
        --btn-bd-color: var(
            --btn-outline-secondary-bd-color,
            var(--secondary-color)
        );
        --btn-text-color-hover: var(
            --btn-outline-secondary-text-color-hover,
            #fff
        );
        --btn-bg-color-hover: var(
            --btn-outline-secondary-bg-color-hover,
            var(--secondary-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-secondary-bd-color-hover,
            var(--secondary-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-secondary-box-shadow-focus,
            0 0 0 0.2rem rgba(108, 117, 125, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-secondary-text-color-disabled,
            var(--secondary-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-secondary-bg-color-disabled,
            #transparent
        );
        --btn-text-color-active: var(
            --btn-outline-secondary-text-color-active,
            #fff
        );
        --btn-bg-color-active: var(
            --btn-outline-secondary-bg-color-active,
            var(--secondary-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-secondary-bd-color-active,
            var(--secondary-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-secondary-box-shadow-active-focus,
            0 0 0 0.2rem rgba(108, 117, 125, 0.5)
        );
    }
`;

const BsButtonSuccessCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --success-color: var(--success, #28a745);
    }

    bs-button[context="success"]:not([outline]),
    bs-button-link[context="success"]:not([outline]),
    bs-button-input[context="success"]:not([outline]) {
        --btn-text-color: var(--btn-success-text-color, #fff);
        --btn-bg-color: var(--btn-success-bg-color, var(--success-color));
        --btn-bd-color: var(--btn-success-bd-color, var(--success-color));
        --btn-text-color-hover: var(--btn-success-text-color-hover, #fff);
        --btn-bg-color-hover: var(--btn-success-bg-color-hover, #218838);
        --btn-bd-color-hover: var(--btn-success-bd-color-hover, #1e7e34);
        --btn-bd-color-focus: var(--btn-success-bd-color-focus, #1e7e34);
        --btn-bg-color-focus: var(--btn-success-bg-color-focus, #218838);
        --btn-text-color-focus: var(--btn-success-text-color-focus, #fff);
        --btn-box-shadow-focus: var(
            --btn-success-box-shadow-focus,
            0 0 0 0.2rem rgba(40, 167, 69, 0.5)
        );
        --btn-text-color-disabled: var(--btn-success-text-color-disabled, #fff);
        --btn-bg-color-disabled: var(
            --btn-success-bg-color-disabled,
            var(--success-color)
        );
        --btn-bd-color-disabled: var(
            --btn-success-bd-color-disabled,
            var(--success-color)
        );
        --btn-text-color-active: var(--btn-success-text-color-active, #fff);
        --btn-bg-color-active: var(--btn-success-bg-color-active, #1e7e34);
        --btn-bd-color-active: var(--btn-success-bd-color-active, #1c7430);
        --btn-box-shadow-active-focus: var(
            --btn-success-box-shadow-active-focus,
            0 0 0 0.2rem rgba(40, 167, 69, 0.5)
        );
    }

    bs-button[context="success"][outline],
    bs-button-link[context="success"][outline],
    bs-button-input[context="success"][outline] {
        --btn-text-color: var(
            --btn-outline-success-text-color,
            var(--success-color)
        );
        --btn-bg-color: var(--btn-outline-success-bg-color, transparent);
        --btn-bd-color: var(
            --btn-outline-success-bd-color,
            var(--success-color)
        );
        --btn-text-color-hover: var(
            --btn-outline-success-text-color-hover,
            #fff
        );
        --btn-bg-color-hover: var(
            --btn-outline-success-bg-color-hover,
            var(--success-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-success-bd-color-hover,
            var(--success-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-success-box-shadow-focus,
            0 0 0 0.2rem rgba(40, 167, 69, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-success-text-color-disabled,
            var(--success-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-success-bg-color-disabled,
            #transparent
        );
        --btn-text-color-active: var(
            --btn-outline-success-text-color-active,
            #fff
        );
        --btn-bg-color-active: var(
            --btn-outline-success-bg-color-active,
            var(--success-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-success-bd-color-active,
            var(--success-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-success-box-shadow-active-focus,
            0 0 0 0.2rem rgba(40, 167, 69, 0.5)
        );
    }
`;

const BsButtonWarningCss = css`
    bs-button,
    bs-button-link,
    bs-button-input {
        --warning-color: var(--warning, #ffc107);
    }

    bs-button[context="warning"]:not([outline]),
    bs-button-link[context="warning"]:not([outline]),
    bs-button-input[context="warning"]:not([outline]) {
        --btn-text-color: var(--btn-warning-text-color, #212529);
        --btn-bg-color: var(--btn-warning-bg-color, var(--warning-color));
        --btn-bd-color: var(--btn-warning-bd-color, var(--warning-color));
        --btn-text-color-hover: var(--btn-warning-text-color-hover, #212529);
        --btn-bg-color-hover: var(--btn-warning-bg-color-hover, #e0a800);
        --btn-bd-color-hover: var(--btn-warning-bd-color-hover, #d39e00);
        --btn-bd-color-focus: var(--btn-warning-bd-color-focus, #d39e00);
        --btn-bg-color-focus: var(--btn-warning-bg-color-focus, #e0a800);
        --btn-text-color-focus: var(--btn-warning-text-color-focus, #fff);
        --btn-box-shadow-focus: var(
            --btn-warning-box-shadow-focus,
            0 0 0 0.2rem rgba(255, 193, 7, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-warning-text-color-disabled,
            #212529
        );
        --btn-bg-color-disabled: var(
            --btn-warning-bg-color-disabled,
            var(--warning-color)
        );
        --btn-bd-color-disabled: var(
            --btn-warning-bd-color-disabled,
            var(--warning-color)
        );
        --btn-text-color-active: var(--btn-warning-text-color-active, #212529);
        --btn-bg-color-active: var(--btn-warning-bg-color-active, #d39e00);
        --btn-bd-color-active: var(--btn-warning-bd-color-active, #c69500);
        --btn-box-shadow-active-focus: var(
            --btn-warning-box-shadow-active-focus,
            0 0 0 0.2rem rgba(255, 193, 7, 0.5)
        );
    }

    bs-button[context="warning"][outline],
    bs-button-link[context="warning"][outline],
    bs-button-input[context="warning"][outline] {
        --btn-text-color: var(
            --btn-outline-warning-text-color,
            var(--warning-color)
        );
        --btn-bg-color: var(--btn-outline-warning-bg-color, transparent);
        --btn-bd-color: var(
            --btn-outline-warning-bd-color,
            var(--warning-color)
        );
        --btn-text-color-hover: var(
            --btn-outline-warning-text-color-hover,
            #212529
        );
        --btn-bg-color-hover: var(
            --btn-outline-warning-bg-color-hover,
            var(--warning-color)
        );
        --btn-bd-color-hover: var(
            --btn-outline-warning-bd-color-hover,
            var(--warning-color)
        );
        --btn-box-shadow-focus: var(
            --btn-outline-warning-box-shadow-focus,
            0 0 0 0.2rem rgba(255, 193, 7, 0.5)
        );
        --btn-text-color-disabled: var(
            --btn-outline-warning-text-color-disabled,
            var(--warning-color)
        );
        --btn-bg-color-disabled: var(
            --btn-outline-warning-bg-color-disabled,
            #transparent
        );
        --btn-text-color-active: var(
            --btn-outline-warning-text-color-active,
            #212529
        );
        --btn-bg-color-active: var(
            --btn-outline-warning-bg-color-active,
            var(--warning-color)
        );
        --btn-bd-color-active: var(
            --btn-outline-warning-bd-color-active,
            var(--warning-color)
        );
        --btn-box-shadow-active-focus: var(
            --btn-outline-warning-box-shadow-active-focus,
            0 0 0 0.2rem rgba(255, 193, 7, 0.5)
        );
    }
`;

export { BsButton, BsButtonBlockCss, BsButtonCommonCss, BsButtonDangerCss, BsButtonDarkCss, BsButtonInfoCss, BsButtonInput, BsButtonLightCss, BsButtonLink, BsButtonLinkCss, BsButtonMixin, BsButtonPrimaryCss, BsButtonSecondaryCss, BsButtonSizeCss, BsButtonSuccessCss, BsButtonWarningCss };
//# sourceMappingURL=index.js.map
